==> ugene_1.12.3+dfsg.orig.tar.xz: ugene-1.12.3+dfsg.orig/src/corelibs/U2View/src/util_smith_waterman/SubstMatrixDialog.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_SUBST_MATRIX_DIALOG_H_
#define _U2_SUBST_MATRIX_DIALOG_H_

#include "ui/ui_SubstMatrixDialogBase.h"

#include <U2Core/global.h>
#include <U2Core/SMatrix.h>

#include <QtGui/QDialog>

namespace U2 {

class U2VIEW_EXPORT SubstMatrixDialog: public QDialog, public Ui::SubstMatrixDialogBase {
    Q_OBJECT
public:
    SubstMatrixDialog(const SMatrix& m, QWidget* parent);

private slots:
    void sl_closeWindow();

    void sl_mouseOnCell(int row, int column);

private:

    void connectGUI();
    void prepareTable();

    int hlBorderColumn;
    int hlBorderRow;
    
    int hlInnerColumn;
    int hlInnerRow;

    SMatrix m;
};

} // namespace

#endif

==> ugene_1.25.0+dfsg.orig.tar.xz: ugene-1.25.0/src/corelibs/U2View/src/util_smith_waterman/SubstMatrixDialog.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_SUBST_MATRIX_DIALOG_H_
#define _U2_SUBST_MATRIX_DIALOG_H_

#include "ui_SubstMatrixDialogBase.h"

#include <U2Core/global.h>
#include <U2Core/SMatrix.h>

#if (QT_VERSION < 0x050000) //Qt 5
#include <QtGui/QDialog>
#else
#include <QtWidgets/QDialog>
#endif

namespace U2 {

class U2VIEW_EXPORT SubstMatrixDialog: public QDialog, public Ui_SubstMatrixDialogBase {
    Q_OBJECT
public:
    SubstMatrixDialog(const SMatrix& m, QWidget* parent);

private slots:
    void sl_closeWindow();

    void sl_mouseOnCell(int row, int column);

private:

    void connectGUI();
    void prepareTable();

    int hlBorderColumn;
    int hlBorderRow;

    int hlInnerColumn;
    int hlInnerRow;

    SMatrix m;

    QPushButton* bttnClose;
};

} // namespace

#endif
